@@ -7,6 +7,8 @@
 #ifndef KPUBLICTRANSPORT_ABSTRACTBACKEND_H
 #define KPUBLICTRANSPORT_ABSTRACTBACKEND_H
 
+#include "kpublictransport_export.h"
+
 #include "reply.h"
 #include "requestcontext_p.h"
 
@@ -35,8 +37,10 @@ class StopoverRequest;
 class VehicleLayoutReply;
 class VehicleLayoutRequest;
 
-/** Abstract base class for transport provider backends. */
-class AbstractBackend
+/** Abstract base class for transport provider backends.
+ *  @internal exported for tooling only
+ */
+class KPUBLICTRANSPORT_EXPORT AbstractBackend
 {
     Q_GADGET
     Q_PROPERTY(QString customCaCertificate WRITE setCustomCaCertificate)
@@ -142,7 +146,13 @@ protected:
 
     static void addAttributions(Reply *reply, std::vector<Attribution> &&attributions);
 
-    template <typename ReqT> inline QVariant requestContext(const ReqT &request) const
+    /** Extract the request context for the current backend from @p request. */
+    template <typename ReqT> inline RequestContext requestContext(const ReqT &request) const
+    {
+        return request.context(this);
+    }
+    /** Extract the backend-specific data from the request context for the current backend from @p request. */
+    template <typename ReqT> inline QVariant requestContextData(const ReqT &request) const
     {
         return request.context(this).backendData;
     }
