@@ -10,6 +10,7 @@
 #include <KPublicTransport/Attribution>
 #include <KPublicTransport/Journey>
 #include <KPublicTransport/Line>
+#include <KPublicTransport/RentalVehicle>
 #include <KPublicTransport/Stopover>
 
 #include <QColor>
@@ -112,6 +113,25 @@ static Location parseLocation(const QJsonObject &obj)
             loc.setIdentifier(QStringLiteral("uic"), code.value(QLatin1String("value")).toString().left(7));
         }
     }
+    const auto id = obj.value(QLatin1String("id")).toString();
+    if (id.startsWith(QLatin1String("poi:osm:node:"))) {
+        loc.setIdentifier(QStringLiteral("osm"), QLatin1Char('n') + QStringView(id).mid(13));
+    }
+
+    const auto poi_type = obj.value(QLatin1String("poi_type")).toObject().value(QLatin1String("id")).toString();
+    if (poi_type == QLatin1String("poi_type:amenity:bicycle_rental")) {
+        RentalVehicleNetwork network;
+        network.setName(obj.value(QLatin1String("properties")).toObject().value(QLatin1String("network")).toString());
+
+        RentalVehicleStation station;
+        station.setNetwork(network);
+        const auto standsObj = obj.value(QLatin1String("stands")).toObject();
+        station.setAvailableVehicles(standsObj.value(QLatin1String("available_bikes")).toInt(-1));
+        station.setCapacity(standsObj.value(QLatin1String("total_stands")).toInt(-1));
+
+        loc.setType(Location::RentedVehicleStation);
+        loc.setData(station);
+    }
 
     return loc;
 }
@@ -135,7 +155,99 @@ static void parseStopDateTime(const QJsonObject &dtObj, Stopover &departure)
         departure.setExpectedDepartureTime(parseDateTime(dtObj.value(QLatin1String("departure_date_time")), departure.stopPoint().timeZone()));
         departure.setExpectedArrivalTime(parseDateTime(dtObj.value(QLatin1String("arrival_date_time")), departure.stopPoint().timeZone()));
     }
+}
 
+static Path parsePathWithInstructionStartCoordinate(const QPolygonF &pathLineString, const QJsonArray &pathArray)
+{
+    std::vector<PathSection> pathSections;
+    pathSections.reserve(pathArray.size());
+    PathSection prevPathSec;
+    int prevPolyIdx = 0;
+    bool isFirstSection = true;
+    for (const auto &pathV : pathArray) {
+        const auto pathObj = pathV.toObject();
+        PathSection pathSec;
+        pathSec.setDescription(pathObj.value(QLatin1String("instruction")).toString());
+        if (pathSec.description().isEmpty()) {
+            pathSec.setDescription(pathObj.value(QLatin1String("name")).toString());
+        }
+
+        if (!isFirstSection) {
+            const auto coordObj = pathObj.value(QLatin1String("instruction_start_coordinate")).toObject();
+            const QPointF coord(coordObj.value(QLatin1String("lon")).toString().toDouble(), coordObj.value(QLatin1String("lat")).toString().toDouble());
+            const auto it = std::min_element(pathLineString.begin() + prevPolyIdx, pathLineString.end(), [coord](QPointF lhs, QPointF rhs) {
+                return Location::distance(lhs.y(), lhs.x(), coord.y(), coord.x()) < Location::distance(rhs.y(), rhs.x(), coord.y(), coord.x());
+            });
+            int polyIdx = std::distance(pathLineString.begin(), it);
+
+            QPolygonF subPoly;
+            subPoly.reserve(polyIdx - prevPolyIdx + 1);
+            std::copy(pathLineString.begin() + prevPolyIdx, pathLineString.begin() + polyIdx + 1, std::back_inserter(subPoly));
+            prevPathSec.setPath(std::move(subPoly));
+            prevPolyIdx = polyIdx;
+            pathSections.push_back(std::move(prevPathSec));
+        } else {
+            isFirstSection = false;
+        }
+        prevPathSec = pathSec;
+    }
+
+    QPolygonF subPoly;
+    subPoly.reserve(prevPolyIdx - pathLineString.size() + 1);
+    std::copy(pathLineString.begin() + prevPolyIdx, pathLineString.end(), std::back_inserter(subPoly));
+    prevPathSec.setPath(std::move(subPoly));
+    pathSections.push_back(std::move(prevPathSec));
+
+    Path path;
+    path.setSections(std::move(pathSections));
+    return path;
+}
+
+static Path parsePathFromLength(const QPolygonF &pathLineString, const QJsonArray &pathArray)
+{
+    std::vector<PathSection> pathSections;
+    pathSections.reserve(pathArray.size());
+    int prevPolyIdx = 0;
+    for (const auto &pathV : pathArray) {
+        const auto pathObj = pathV.toObject();
+        PathSection pathSec;
+        pathSec.setDescription(pathObj.value(QLatin1String("instruction")).toString());
+        if (pathSec.description().isEmpty()) {
+            pathSec.setDescription(pathObj.value(QLatin1String("name")).toString());
+        }
+
+        int polyIdx = prevPolyIdx + 1;
+        const auto length = pathObj.value(QLatin1String("length")).toInt();
+        for (float l = 0.0f, prevDelta = std::numeric_limits<float>::max(); polyIdx < pathLineString.size(); ++polyIdx) {
+            l += Location::distance(pathLineString.at(polyIdx - 1).y(), pathLineString.at(polyIdx - 1).x(), pathLineString.at(polyIdx).y(), pathLineString.at(polyIdx).x());
+            auto delta = length - l;
+            if (delta <= 0) {
+                if (prevDelta < -delta) {
+                    --polyIdx;
+                }
+                break;
+            }
+            prevDelta = delta;
+        }
+
+        QPolygonF subPoly;
+        subPoly.reserve(polyIdx - prevPolyIdx + 1);
+        std::copy(pathLineString.begin() + prevPolyIdx, pathLineString.begin() + std::min(polyIdx + 1, pathLineString.size()), std::back_inserter(subPoly));
+        pathSec.setPath(std::move(subPoly));
+        prevPolyIdx = polyIdx;
+        pathSections.push_back(std::move(pathSec));
+    }
+
+    // if there's a trailing polygon end, attached that to the last section
+    if (prevPolyIdx + 1 < pathLineString.size()) {
+        auto poly = pathSections.back().path();
+        std::copy(pathLineString.begin() + prevPolyIdx + 1, pathLineString.end(), std::back_inserter(poly));
+        pathSections.back().setPath(std::move(poly));
+    }
+
+    Path path;
+    path.setSections(std::move(pathSections));
+    return path;
 }
 
 JourneySection NavitiaParser::parseJourneySection(const QJsonObject &obj) const
@@ -181,10 +293,29 @@ JourneySection NavitiaParser::parseJourneySection(const QJsonObject &obj) const
     const auto typeStr = obj.value(QLatin1String("type")).toString();
     if (typeStr == QLatin1String("public_transport")) {
         section.setMode(JourneySection::PublicTransport);
-    } else if (typeStr == QLatin1String("transfer")) {
+    // TODO we have no type for parking/rent/return yet
+    } else if (typeStr == QLatin1String("transfer") || typeStr == QLatin1String("park") ||
+        typeStr == QLatin1String("bss_rent") || typeStr == QLatin1String("bss_put_back")) {
         section.setMode(JourneySection::Transfer);
     } else if (typeStr == QLatin1String("street_network") || typeStr == QLatin1String("walking") || typeStr == QLatin1String("crow_fly")) {
-        section.setMode(JourneySection::Walking);
+        const auto modeStr = obj.value(QLatin1String("mode")).toString();
+        if (modeStr == QLatin1String("bike")) {
+            if (section.from().type() == Location::RentedVehicleStation) {
+                section.setMode(JourneySection::RentedVehicle);
+                RentalVehicle v;
+                v.setType(RentalVehicle::Bicycle);
+                v.setNetwork(section.from().rentalVehicleStation().network());
+                section.setRentalVehicle(v);
+            } else {
+                section.setMode(JourneySection::IndividualTransport);
+                section.setIndividualTransport({IndividualTransport::Bike, IndividualTransport::None});
+            }
+        } else if (modeStr == QLatin1String("car")) {
+            section.setMode(JourneySection::IndividualTransport);
+            section.setIndividualTransport({IndividualTransport::Car, IndividualTransport::None});
+        } else {
+            section.setMode(JourneySection::Walking);
+        }
         section.setDistance(obj.value(QLatin1String("geojson")).toObject().value(QLatin1String("properties")).toArray().at(0).toObject().value(QLatin1String("length")).toInt());
     } else if (typeStr == QLatin1String("waiting")) {
         section.setMode(JourneySection::Waiting);
@@ -212,7 +343,17 @@ JourneySection NavitiaParser::parseJourneySection(const QJsonObject &obj) const
     section.setCo2Emission(emissionObj.value(QLatin1String("value")).toDouble(-1));
 
     const auto pathLineString = GeoJson::readLineString(obj.value(QLatin1String("geojson")).toObject());
-    if (!pathLineString.empty()) {
+    const auto pathArray = obj.value(QLatin1String("path")).toArray();
+    if (!pathArray.empty()) {
+        const auto hasInstrStartCoordinate = pathArray.at(0).toObject().contains(QLatin1String("instruction_start_coordinate"));
+        Path path;
+        if (hasInstrStartCoordinate) {
+            path = parsePathWithInstructionStartCoordinate(pathLineString, pathArray);
+        } else {
+            path = parsePathFromLength(pathLineString, pathArray);
+        }
+        section.setPath(std::move(path));
+    } else if (!pathLineString.isEmpty()) {
         Path path;
         PathSection pathSection;
         pathSection.setPath(pathLineString);
