@@ -28,6 +28,7 @@ public:
         Regular,
         Any
     };
+    Q_ENUM(Type)
     KPUBLICTRANSPORT_PROPERTY(Type, type, setType)
 
     /** ISO 3166-1/2 codes of covered regions.
@@ -52,6 +53,9 @@ public:
     /** Checks whether @p loc is covered by this area. */
     bool coversLocation(const Location &loc) const;
 
+    /** Checks whether this includes the entire country @p country. */
+    bool hasNationWideCoverage(const QString &country) const;
+
     /** Read a single coverage area information from a JSON object
      *  in Transport API Repository format.
      */
